<template>
  <div class="data-chart-container">
    <el-card class="data-card" :body-style="{ height: '100%' }">
      <div class="card-content">
        <div class="title-container">
          <h1>运维监控报表</h1>
          <div class="select-container">
            <el-select v-model="params.unitId" placeholder="请选择运维公司" @change="showData">
              <el-option v-for="item in options" :key="item.label" :label="item.label" :value="item.value">
              </el-option>
            </el-select>
          </div>
          <div class="date-container">
            <el-date-picker type="monthrange" v-model="params.dateRange" range-separator="至" start-placeholder="开始月份"
              end-placeholder="结束月份" @change="showData">
            </el-date-picker>
          </div>
        </div>
        <div class="chart-container">
          <div id="chartContent" ref="chartContent"></div>
        </div>
      </div>
    </el-card>
  </div>
</template>

<script>
import * as echarts from 'echarts';
import { ywUnitList, monitor } from "@/api/platform/home";
let lineChart = null;
let observer = null;
export default {
  name: 'DataChart',
  data() {
    return {
      params: {
        dateRange: '',
        unitId: ''
      },
      options: [],
      dataList: [],
    }
  },
  methods: {
    initChart() {
      const sortedKeys  = Object.keys(this.acitveData.state)
        .sort(); // 按照字符串的字典序对键进行排序
      const option = {
        legend: {
          right: 'right',
          top: 'top',
          orient: "vertical",
          icon: 'rect',
          data: [
            {
              name: '正常数',
              itemStyle: {
                color: 'rgba(62, 144, 247, 1)'
              }
            },
            {
              name: '异常数',
              itemStyle: {
                color: 'rgba(85, 192, 191, 1)'
              }
            },
          ],
        },
        grid: {
          left: 0,
          right: 0,
          bottom: 0,
          top: '20%',
          containLabel: true
        },
        tooltip: {},
        xAxis: {
          type: 'category',
          data: sortedKeys,
        },
        yAxis: {},
        series: [
          {
            name: '正常数',
            data: sortedKeys.map(key => this.acitveData.state[key]),
            type: 'line',
            itemStyle: {
              color: 'rgba(62, 144, 247, 1)'
            }
          },
          {
            name: '异常数',
            data: sortedKeys.map(key => this.acitveData.state2[key]),
            type: 'line',
            itemStyle: {
              color: 'rgba(85, 192, 191, 1)'
            }
          }
        ]
      };
      lineChart.setOption(option, true);
    },


    showData() {
      monitor(this.params).then(res => {
        this.acitveData = res.data;
        if (Object.keys(this.acitveData).length === 0) {
          this.acitveData = {
              "name": "",
              "state": {},
              "state2": {}
          }
        }
        lineChart = echarts.init(this.$refs.chartContent);
        this.initChart();
        this.observe();
      })
    },

    // 监听变化
    observe() {
      if (!observer) {
        observer = new ResizeObserver(entries => {
          this.handleResize();
        })
      }
      observer.observe(this.$refs.chartContent);
    },
    // 窗口变换
    handleResize() {
      if (lineChart) {
        lineChart.resize();
      }
    }

  },
  mounted() {
    ywUnitList().then(res => {
      this.options = res.data.data.map(item => {
        return {
          label: item.value,
          value: item.id
        }
      })
      if (this.params.unitId === '') {
        this.params.unitId = this.options[0].value;
      }
      this.showData();
    })
  },
  beforeDestroy() {
    if (lineChart) {
      lineChart.dispose();
      observer.unobserve(this.$refs.chartContent);
    }
  },
}
</script>

<style lang="scss" scoped>
.data-chart-container {
  height: 400px;
  margin-bottom: 20px;

  .data-card {
    height: 100%;

    .card-content {
      width: 100%;
      height: 100%;
      position: relative;
    }
  }
}

.title-container {
  position: absolute;
  display: flex;
  justify-content: space-between;
  align-items: center;
  z-index: 2;

  .more-button {
    cursor: pointer;
    font-size: 16px;
    padding: 0 10px;
  }
}

.chart-container {

  width: 100%;
  height: 100%;

  #chartContent {
    width: 100%;
    height: 100%;
  }
}

.select-container {
  margin: 0 20px;
  width: 180px;
}
</style>
